|
|
|
| Description |
| Fs2dot is to help us create a visualisation of an algorithm written in
Feldspar by converting its graph into dot format -- which can be further
processed by the Graphviz suite.
|
|
| Synopsis |
|
|
|
| Documentation |
|
|
| :: Program prg | | | => prg | Feldspar function
| | -> DOTSource | DOT language source
| | fs2dot takes a Feldspar function as its argument and produces DOT language
source.
|
|
|
|
| :: Program prg | | | => FilePath | output filename
| | -> prg | Feldspar function
| | -> IO () | | | writeDot creates a DOT language format source file. Expected arguments
are the desired filename and the Feldspar function to be output in DOT
language.
|
|
|
|
| This is for clarity.
|
|
| Produced by Haddock version 2.6.1 |